/// <reference types="./types" />
import "./assets/less/index.less";
import VditorMethod from "./method";
declare class Vditor extends VditorMethod {
    readonly version: string;
    vditor: IVditor;
    /**
     * @param id 要挂载 Vditor 的元素或者元素 ID。
     * @param options Vditor 参数
     */
    constructor(id: string | HTMLElement, options?: IOptions);
    /** 设置主题 */
    setTheme(theme: "dark" | "classic", contentTheme?: string, codeTheme?: string, contentThemePath?: string): void;
    /** 获取 Markdown 内容 */
    getValue(): string;
    /** 设置编辑器主题 */
    setContentTheme(contentTheme: string, contentThemePath?: string): void;
    /** 设置代码主题 */
    setCodeTheme(codeTheme: string): void;
    /** 获取编辑器当前编辑模式 */
    getCurrentMode(): "sv" | "wysiwyg" | "ir";
    /** 聚焦到编辑器 */
    focus(): void;
    /** 让编辑器失焦 */
    blur(): void;
    /** 禁用编辑器 */
    disabled(): void;
    /** 解除编辑器禁用 */
    enable(): void;
    /** 返回选中的内容，
     * 默认情况下返回纯文本
     * 之后wysiwyg模式才可以返回md或者html */
    getSelection(type?: string): string;
    /** 设置预览区域内容 */
    renderPreview(value?: string): void;
    /** 获取焦点位置 */
    getCursorPosition(): {
        left: number;
        top: number;
    };
    /** 上传是否还在进行中 */
    isUploading(): boolean;
    /** 清除缓存 */
    clearCache(): void;
    /** 禁用缓存 */
    disabledCache(): void;
    /** 启用缓存 */
    enableCache(): void;
    /** HTML 转 md */
    html2md(value: string): string;
    /** markdown 转 JSON 输出 */
    exportJSON(value: string): string;
    /** 获取 HTML */
    getHTML(): string;
    /** 消息提示。time 为 0 将一直显示 */
    tip(text: string, time?: number): void;
    /** 设置预览模式 */
    setPreviewMode(mode: "both" | "editor"): void;
    /** 删除选中内容 */
    deleteValue(): void;
    /** 更新选中内容 */
    updateValue(value: string): void;
    /** 在焦点处插入内容，并默认进行 Markdown 渲染 */
    insertValue(value: string, render?: boolean): void;
    /** 设置编辑器内容 */
    setValue(markdown: string, clearStack?: boolean): void;
    /** 清空 undo & redo 栈 */
    clearStack(): void;
    /** 销毁编辑器 */
    destroy(): void;
    /** 获取评论 ID */
    getCommentIds(): ICommentsData[];
    /** 高亮评论 */
    hlCommentIds(ids: string[]): void;
    /** 取消评论高亮 */
    unHlCommentIds(ids: string[]): void;
    /** 删除评论 */
    removeCommentIds(removeIds: string[]): void;
    /** 切换模式 **/
    changeEditMode(targetMode: string): void;
    /** 隐藏Toolbar **/
    hideToorBar(): void;
    /** 增加不同种类的block **/
    addBlock(type: string): void;
    addFormat(type: string): void;
    /** 导出HTML **/
    exportHTML(autoDownload?: boolean): string;
    /** 导出PDF **/
    exportPDF(autoDownload?: boolean): Document;
    /** 跳转到对应标题处 **/
    scrollToHeading(info: number[]): void;
    /** 清除样式 **/
    removeFormat(): void;
    /** 设置打字机模式 **/
    setTypewriterMode(enable: boolean): void;
    /** 获得当前焦点位置 **/
    getEditorRange(): Range;
    /** 根据当前模式设置焦点, 并进行跳转
     *  如果不传range, 或者传的range属于当前模式的界面中，则需要跳转到开头 **/
    setEditorRange(range?: Range): void;
    setLatexEngine(engine: string): void;
    setCodeBlockLineNumber(enable: boolean): void;
    setAutoSpace(enable: boolean): void;
    /** 设置自动矫正术语 */
    setAutoFixTermTypo(enable: boolean): void;
    /** 设置悬浮工具框的内容 */
    setPopoverToolbar(options: IOptions["popoverToolbar"]): void;
    /** 设置是否可以编辑 */
    setEditable(enable: boolean): void;
    private init;
}
export default Vditor;
